@@ -1,5 +1,5 @@
 # coding=utf-8
-__version__ = "6.0.24"
+__version__ = "6.0.31"
 
 from subprocess import CalledProcessError, check_output
 import sys
@@ -38,7 +38,6 @@ def check_no_incompatible():
 
 check_no_incompatible()
 
-
 from zuper_commons.logs import ZLogger
 
 dclogger = logger = ZLogger(__name__)
@@ -54,6 +53,3 @@ from .challenge_solution import *
 from .challenge_results import *
 from .cie_concrete import *
 from .follow import *
-
-from .make_readmes import make_readmes_main as make_readmes_main
-from .make_readme_templates import make_readmes_templates_main
