@@ -3,7 +3,7 @@ import subprocess
 import sys
 from dataclasses import dataclass
 from typing import Optional
-
+from .constants import get_important_env_build_args, IMPORTANT_ENVS
 from zuper_commons.timing import now_utc
 from zuper_commons.types import ZException
 
@@ -113,15 +113,7 @@ def submission_build(username: str, registry: Optional[str], no_cache: bool = Fa
     with open(df) as _:
         df_contents = _.read()
 
-    vnames = {
-        "AIDO_REGISTRY": "docker.io",
-        "PIP_INDEX_URL": "https://pypi.org/simple",
-    }
-
-    for vname, default_value in vnames.items():
-        if vname in df_contents:
-            value = os.environ.get(vname, default_value)
-            cmd.extend(["--build-arg", f"{vname}={value}"])
+    cmd.extend(get_important_env_build_args(df_contents))
 
     if no_cache:
         cmd.append("--no-cache")
@@ -140,7 +132,7 @@ def submission_build(username: str, registry: Optional[str], no_cache: bool = Fa
     (p_stdout, p_stderr) = p.communicate()
     if p.returncode != 0:
         msg = "Could not run docker push. Exit code %s." % p.returncode
-        msg += "\n\nThis is likely to be because you have not logged in to dockerhub using `docker login`."
+        # msg += "\n\nThis is likely to be because you have not logged in to dockerhub using `docker login`."
         raise ZException(msg, command=" ".join(cmd), retcode=p.returncode, stdout=p_stdout, stderr=p_stderr)
 
     dclogger.info("After pushing; please wait...")
